@@ -34,7 +34,7 @@
 #
 package App::Dochazka::CLI;
 
-use 5.006;
+use 5.012;
 use strict;
 use warnings FATAL => 'all';
 
@@ -53,11 +53,11 @@ App::Dochazka::CLI - Dochazka command line client
 
 =head1 VERSION
 
-Version 0.184
+Version 0.191
 
 =cut
 
-our $VERSION = '0.184';
+our $VERSION = '0.191';
 
 
 
@@ -75,17 +75,21 @@ Dochazka command line client.
 L<App::Dochazka::CLI> is the Command Line Interface (CLI) component of the
 Dochazka Attendance & Time Tracking system. 
 
-It implements a number of commands, which are documented in L<App::Dochazka::CLI::Guide>.
+In order to work, the CLI must be pointed at a running L<App::Dochazka::REST>
+(i.e., Dochazka REST server) instance by setting the C<< MREST_CLI_URI_BASE >>
+site configuration parameter. 
+
+Detailed documentation covering configuration, deployment, and the commands
+that can be used with the CLI can be found in L<App::Dochazka::CLI::Guide>.
+
+This module is used to store some "global" package variables that are used
+throughout the CLI code base.
 
 
 =head1 PACKAGE VARIABLES AND EXPORTS
 
 =over
 
-=item * C<< $prompt_date >>
-
-The date displayed in the prompt -- see C<bin/dochazka-cli>
-
 =item * C<< $current_emp >>
 
 The L<App::Dochazka::Model::Employee> object of the current employee.
@@ -98,17 +102,49 @@ The privlevel of the current employee.
 
 Tells parser whether to display debug messages
 
+=item * C<< $prompt_century >>
+
+The century component of C<< $prompt_date >>; see L<App::Dochazka::CLI::Util>
+
+=item * C<< $prompt_date >>
+
+The date displayed in the prompt -- see C<bin/dochazka-cli> and L<App::Dochazka::CLI::Util>
+
+=item * C<< $prompt_day >>
+
+The day component of C<< $prompt_date >>; see L<App::Dochazka::CLI::Util>
+
+=item * C<< $prompt_month >>
+
+The month component of C<< $prompt_date >>; see L<App::Dochazka::CLI::Util>
+
+=item * C<< $prompt_year >>
+
+The year component of C<< $prompt_date >>; see L<App::Dochazka::CLI::Util>
+
 =back
 
 =cut
 
-our ( $prompt_date, $current_emp, $current_priv, $debug_mode, $message );
 our @EXPORT_OK = qw( 
-    $prompt_date 
     $current_emp 
     $current_priv 
     $debug_mode
+    $prompt_century
+    $prompt_date 
+    $prompt_day
+    $prompt_month
+    $prompt_year
+);
+our ( 
+    $current_emp, 
+    $current_priv, 
+    $debug_mode, 
+    $prompt_date, 
+    $prompt_century, 
+    $prompt_year, 
+    $prompt_month, 
+    $prompt_day, 
 );
 
 1;
-
