@@ -41,6 +41,7 @@ use warnings;
 use App::CELL qw( $CELL );
 use App::Dochazka::CLI::Commands::Activity qw( activity_all );
 use App::Dochazka::CLI::Commands::Employee qw( 
+    employee_list
     employee_profile
     set_employee_self_sec_id 
     set_employee_other_sec_id 
@@ -98,11 +99,11 @@ App::Dochazka::CLI::CommandMap - Command map
 
 =head1 VERSION
 
-Version 0.184
+Version 0.191
 
 =cut
 
-our $VERSION = '0.184';
+our $VERSION = '0.191';
 
 
 
@@ -111,8 +112,6 @@ our $VERSION = '0.184';
 
 =cut
 
-our @EXPORT_OK = qw( $dispatch_map generate_semantic_tree look_up_command $semantic_tree );
-
 # bring in the _method... functions
 require App::Dochazka::CLI::Commands::RestTest::Activity;
 require App::Dochazka::CLI::Commands::RestTest::Employee;
@@ -122,7 +121,7 @@ require App::Dochazka::CLI::Commands::RestTest::Priv;
 require App::Dochazka::CLI::Commands::RestTest::Schedule;
 require App::Dochazka::CLI::Commands::RestTest::Top;
 
-my $dispatch_map = { 
+our $dispatch_map = { 
 
     # Top-level commands
     "GET" => \&_method,
@@ -282,6 +281,38 @@ my $dispatch_map = {
     "PUT EMPLOYEE CURRENT PRIV" => \&_method_employee_current_priv,
     "POST EMPLOYEE CURRENT PRIV" => \&_method_employee_current_priv,
     "DELETE EMPLOYEE CURRENT PRIV" => \&_method_employee_current_priv,
+    "GET EMPLOYEE EID" => \&_method_employee_eid,
+    "PUT EMPLOYEE EID" => \&_method_employee_eid,
+    "POST EMPLOYEE EID" => \&_method_employee_eid,
+    "DELETE EMPLOYEE EID" => \&_method_employee_eid,
+    "GET EMPLOYEE EID _JSON" => \&_method_employee_eid_json,
+    "PUT EMPLOYEE EID _JSON" => \&_method_employee_eid_json,
+    "POST EMPLOYEE EID _JSON" => \&_method_employee_eid_json,
+    "DELETE EMPLOYEE EID _JSON" => \&_method_employee_eid_json,
+    "GET EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
+    "PUT EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
+    "POST EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
+    "DELETE EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
+    "GET EMPLOYEE LIST" => \&_method_employee_list,
+    "PUT EMPLOYEE LIST" => \&_method_employee_list,
+    "POST EMPLOYEE LIST" => \&_method_employee_list,
+    "DELETE EMPLOYEE LIST" => \&_method_employee_list,
+    "GET EMPLOYEE LIST _TERM" => \&_method_employee_list_priv,
+    "PUT EMPLOYEE LIST _TERM" => \&_method_employee_list_priv,
+    "POST EMPLOYEE LIST _TERM" => \&_method_employee_list_priv,
+    "DELETE EMPLOYEE LIST _TERM" => \&_method_employee_list_priv,
+    "GET EMPLOYEE NICK" => \&_method_employee_nick,
+    "PUT EMPLOYEE NICK" => \&_method_employee_nick,
+    "POST EMPLOYEE NICK" => \&_method_employee_nick,
+    "DELETE EMPLOYEE NICK" => \&_method_employee_nick,
+    "GET EMPLOYEE NICK _JSON" => \&_method_employee_nick_json,
+    "PUT EMPLOYEE NICK _JSON" => \&_method_employee_nick_json,
+    "POST EMPLOYEE NICK _JSON" => \&_method_employee_nick_json,
+    "DELETE EMPLOYEE NICK _JSON" => \&_method_employee_nick_json,
+    "GET EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
+    "PUT EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
+    "POST EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
+    "DELETE EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
     "GET EMPLOYEE SEARCH" => \&_method_employee_search,
     "PUT EMPLOYEE SEARCH" => \&_method_employee_search,
     "POST EMPLOYEE SEARCH" => \&_method_employee_search,
@@ -298,30 +329,6 @@ my $dispatch_map = {
     "PUT EMPLOYEE SELF PRIV" => \&_method_employee_self_priv,
     "POST EMPLOYEE SELF PRIV" => \&_method_employee_self_priv,
     "DELETE EMPLOYEE SELF PRIV" => \&_method_employee_self_priv,
-    "GET EMPLOYEE EID" => \&_method_employee_eid,
-    "PUT EMPLOYEE EID" => \&_method_employee_eid,
-    "POST EMPLOYEE EID" => \&_method_employee_eid,
-    "DELETE EMPLOYEE EID" => \&_method_employee_eid,
-    "GET EMPLOYEE EID _JSON" => \&_method_employee_eid_json,
-    "PUT EMPLOYEE EID _JSON" => \&_method_employee_eid_json,
-    "POST EMPLOYEE EID _JSON" => \&_method_employee_eid_json,
-    "DELETE EMPLOYEE EID _JSON" => \&_method_employee_eid_json,
-    "GET EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
-    "PUT EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
-    "POST EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
-    "DELETE EMPLOYEE EID _NUM" => \&_method_employee_eid_num,
-    "GET EMPLOYEE NICK" => \&_method_employee_nick,
-    "PUT EMPLOYEE NICK" => \&_method_employee_nick,
-    "POST EMPLOYEE NICK" => \&_method_employee_nick,
-    "DELETE EMPLOYEE NICK" => \&_method_employee_nick,
-    "GET EMPLOYEE NICK _JSON" => \&_method_employee_nick_json,
-    "PUT EMPLOYEE NICK _JSON" => \&_method_employee_nick_json,
-    "POST EMPLOYEE NICK _JSON" => \&_method_employee_nick_json,
-    "DELETE EMPLOYEE NICK _JSON" => \&_method_employee_nick_json,
-    "GET EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
-    "PUT EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
-    "POST EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
-    "DELETE EMPLOYEE NICK _TERM" => \&_method_employee_nick_term,
 
     # Interval commands
     "GET INTERVAL" => \&_method_interval,
@@ -550,6 +557,8 @@ my $dispatch_map = {
 
     # Employee commands
     "EMPLOYEE" => \&employee_profile,
+    "EMPLOYEE LIST" => \&employee_list,
+    "EMPLOYEE LIST _TERM" => \&employee_list,
     "EMPLOYEE PROFILE" => \&employee_profile,
     "EMPLOYEE SHOW" => \&employee_profile,
     "EMPLOYEE_SPEC" => \&employee_profile,
@@ -686,88 +695,10 @@ my $dispatch_map = {
 
 };
 
-our $semantic_tree = {};
 
 
 =head1 FUNCTIONS
 
-=head2 generate_semantic_tree
-
-Generate the semantic context tree.
-
-The set of keys of C<< %$dispatch_map >> contains all the possible commands,
-expressed as tokens. The semantic context tree is generated from the dispatch
-map keys. Each level of the tree corresponds to a number of tokens - so the 
-set of level-one nodes represents the set of all possible tokens that can 
-appear in the first position. These are children of the root node.
-
-All nodes at level two have a parent in level one, etc. The set of immediate
-child nodes of any given node corresponds to the set of all possible tokens
-that can follow that token.
-
-=cut
-
-sub generate_semantic_tree {
-    my ( $dm ) = @_;
-    #
-    # ( if $dm is given -- e.g., for testing --, then use it. Otherwise, use
-    # the $dispatch_map package variable )
-    #
-    if ( ! $dm ) {
-        $dm = $dispatch_map;
-    }
-
-    my $tree = {};
-
-    foreach my $cmd ( keys %$dm ) {
-        
-        # split the command into tokens
-        my @tokens = split( ' ', $cmd );
-        
-        # walk the tokens - $subtree is a pointer into $tree
-        my $subtree = $tree;
-        for ( my $i = 0; $i < @tokens; $i += 1 ) {
-            my $token = $tokens[$i];
-            if ( ! exists( $subtree->{ $token } ) ) {
-                # create new node
-                $subtree->{ $token } = {};
-            }
-            # add child to existing node
-            $subtree = $subtree->{ $token };
-        }
-        
-    }
-
-    # return the tree we built
-    #print Dumper( $tree ), "\n";
-    return $tree;
-}
-
-
-=head2 look_up_command
-
-Given a normalized command string such as "GET BUGREPORT", look it up in the
-dispatch map and return the corresponding coderef, or nothing if the lookup
-fails.
-
-=cut
-
-sub look_up_command {
-    my ( $cmd ) = @_;
-
-    # check for undef and empty string
-    return unless defined( $cmd ) and $cmd =~ m/\S/;
-
-    # check for a match
-    if ( my $coderef = $dispatch_map->{ uc( $cmd ) } ) {
-        return $coderef;
-    }
-
-    # failure - return nothing
-    return;
-}
-
-
 =head2 go_exit
 
 Return the "magic" status code that causes dochazka-cli to exit.
