@@ -62,11 +62,11 @@ App::Dochazka::CLI::Commands::Employee - Employee commands
 
 =head1 VERSION
 
-Version 0.184
+Version 0.191
 
 =cut
 
-our $VERSION = '0.184';
+our $VERSION = '0.191';
 
 
 
@@ -75,6 +75,7 @@ our $VERSION = '0.184';
 =cut
 
 our @EXPORT_OK = qw( 
+    employee_list
     employee_profile
     set_employee_self_sec_id 
     set_employee_other_sec_id
@@ -132,6 +133,34 @@ sub employee_profile {
     return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', payload => $message );
 }
 
+
+=head3 employee_list
+
+EMPLOYEE LIST
+EMPLOYEE LIST _TERM
+
+=cut
+
+sub employee_list {
+    my ( $ts, $th ) = @_;
+
+    # parse test
+    return parse_test( $ts, $th ) if $ts eq 'PARSE_TEST';
+
+    my $priv;
+    my $status = ( $priv = $th->{'_TERM'} )
+        ? send_req( 'GET', "employee/list/$priv" )
+        : send_req( 'GET', "employee/list" );
+
+    $priv = $priv || 'all';
+
+    return $status unless $status->ok;
+    return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION',
+        payload => "\nList of employees with priv level ->$priv<-\n    " .
+                   join( "\n    ", @{ $status->payload } ) .  "\n" );
+}
+
+
 =head3 set_employee_self_sec_id
 
 SET EMPLOYEE SEC_ID _TERM
