@@ -42,11 +42,11 @@ App::Dochazka::CLI::Guide - Dochazka CLI Guide
 
 =head1 VERSION
 
-Version 0.184
+Version 0.191
 
 =cut
 
-our $VERSION = '0.184';
+our $VERSION = '0.191';
 
 
 
@@ -59,13 +59,13 @@ The CLI commands can be divided into four categories:
 
 =over
 
-=item Commands for generating HTTP requests
+=item L<"Commands for generating HTTP requests">
 
-=item Commands for Dochazka administrators
+=item L<"Commands for Dochazka administrators">
 
-=item Commands for Dochazka supervisors
+=item L<"Commands for Dochazka supervisors">
 
-=item Commands for Dochazka users
+=item L<"Commands for Dochazka users">
 
 =back
 
@@ -216,6 +216,20 @@ force a lookup on a particular property:
 Note that there must not be any whitespace before or after the equal sign.
 
 
+=head3 Get list of employees
+
+Commands to list all employees, or just those with a given
+privilege level:
+
+    EMPLOYEE LIST             # lists all employees
+    EMPLOYEE LIST admin
+    EMPLOYEE LIST active
+    EMPLOYEE LIST inactive
+    EMPLOYEE LIST passerby
+
+Only nicks are shown, in alphabetical order.
+
+
 =head3 Create a new employee 
 
 If you are using LDAP authentication, your employees are in the LDAP database
@@ -656,10 +670,82 @@ Provided the employee has a schedule defined, it can be displayed by typing:
 
 =head3 Enter an interval
 
-    INTERVAL $ACTIVITY_CODE $TIMESTAMP_BEGIN $TIMESTAMP_END
-    INTERVAL $ACTIVITY_CODE $TIMESTAMP_BEGIN - $TIMESTAMP_END
+=head4 "Canonical" form
+
+The canonical way to enter an attendance interval:
+
+    INTERVAL $TIME_BEGIN $TIME_END $ACTIVITY_CODE $DESCRIPTION
+    INTERVAL $TIME_BEGIN - $TIME_END $ACTIVITY_CODE $DESCRIPTION
+
+Use the above command variant if you need to enter the date along with the
+time, or if the interval begins and ends on a different date. Example:
+
+    INTERVAL 2015-04-27 08:00 - 2015-04-27 12:00 WORK Prepare notes for meeting
+
+If the date is omitted, the "prompt date" will be used:
+
+    INTERVAL 08:00 - 12:00 WORK Prepare notes for meeting
+
+If a beginning date is specified, but no ending date, the beginning date will
+be applied to the end as well:
+
+    INTERVAL 2015-04-28 12:30 - 16:30 WORK Wait for Godot
+    
+=head4 Time range
+
+Another way to omit the date (default to the prompt date) is to enter a time range:
+
+    INTERVAL $TIME_RANGE $ACTIVITY_CODE $DESCRIPTION
+
+Example:
+
+    INTERVAL 8:00-9:00 MEDICAL_LEAVE Doctor's appointment
+
+Optionally, a date can be specified before the time range:
+
+    INTERVAL 2015-04-28 8:00-9:00 MEDICAL_LEAVE Doctor's appointment
+
+
+=head3 Fetch (i.e., view) intervals 
+
+There are many commands for viewing intervals. In all cases, the term FETCH is optional
+
+=head4 All intervals on the prompt date
+
+    INTERVAL [FETCH]
+
+The simplest form; displays the list of intervals for the
+prompt date.
+
+=head4 All intervals on a specified date
+
+    INTERVAL [FETCH] $DATE
+
+Fetch all intervals on the given date. Example:
+
+    INTERVAL FETCH 2015-04-28
+
+=head4 All intervals between a range of dates
+
+    INTERVAL [FETCH] $DATE_BEGIN $DATE_END
+    INTERVAL [FETCH] $DATE_BEGIN - $DATE_END
+
+Fetch all intervals from C<$DATE_BEGIN> to C<$DATE_END>.
+
+=head4 All intervals in a given month
+
+    INTERVAL [FETCH] $MONTH
+    INTERVAL [FETCH] $MONTH $YEAR
+
+The month can be given either in English (only first three letters are
+necessary) or as a numeric value. Example:
+
+    INTERVAL APR
+    INTERVAL FETCH 4
+
+Both of these commands fetch all the employee's intervals that fall within
+April of the prompt year.
 
 =cut
 
-
 1;
