@@ -41,7 +41,7 @@ use warnings FATAL => 'all';
 use App::CELL qw( $CELL );
 use App::Dochazka::CLI qw( $debug_mode );
 use App::Dochazka::CLI::TokenMap qw( $regex_map );
-use App::Dochazka::CLI::CommandMap qw( generate_semantic_tree $semantic_tree look_up_command );
+use App::Dochazka::CLI::CommandMap;
 use Data::Dumper;
 use Exporter 'import';
 use Web::MREST::CLI::UserAgent qw( send_req );
@@ -55,11 +55,11 @@ App::Dochazka::CLI::Parser - Parser module
 
 =head1 VERSION
 
-Version 0.184
+Version 0.191
 
 =cut
 
-our $VERSION = '0.184';
+our $VERSION = '0.191';
 
 
 
@@ -67,6 +67,12 @@ our $VERSION = '0.184';
 
 =over
 
+=item C<< generate_semantic_tree >>
+
+Populate the C<< $semantic_tree >> package variable.
+
+=item C<< lookup_command >>
+
 =item C<< parse >>
 
 Parse the command string entered by the user.
@@ -80,50 +86,134 @@ Given a state expressed as a stack of tokens, return list of possible tokens.
 Given a command string, process it (by parsing, calling the handler, etc.) and
 return the result.
 
+=item C<< $semantic_tree >>
+
+The semantic tree is a traversable tree representation of the CLI commands,
+i.e. the keys of the dispatch map C<< $App::Dochazka::CLI::CommandMap::dispatch_map >>
+
 =back
 
 =cut
 
-our @EXPORT_OK = qw( parse possible_words process_command );
+our @EXPORT_OK = qw( 
+    generate_semantic_tree 
+    look_up_command 
+    parse 
+    possible_words 
+    process_command 
+    $semantic_tree 
+);
+our $semantic_tree;
 
 
 
 
 =head1 FUNCTIONS
 
-=head2 process_command
+=head2 generate_semantic_tree
 
-Given a command entered by the user, process it and return the result.
+Generate the semantic context tree.
+
+The set of keys of C<< %$dispatch_map >> contains all the possible commands,
+each expressed as a sequence of tokens. The semantic context tree is generated
+from the dispatch map keys. Each node of the tree represents a possible token
+and the set of nodes at depth n of the tree is the set of possible tokens in
+the nth position within the command. 
+
+Taking, for example, a dispatch map consisting of the following two commands:
+
+    ABE BABEL CAROL
+    DALE EARL JENSEN PARLOR
+    DALE TWIT
+
+The semantic tree would be:
+
+    (root)
+    |
+    +-----------+
+    |           |
+    ABE        DALE
+    |           |
+    |           +------+
+    |           |      |
+    BABEL      EARL   TWIT
+    |           |
+    CAROL      JENSEN
+                |
+               PARLOR
+
+The point of this exercise is to facilitate command completion. If two a single
+token ABE has been entered by the user and <TAB> is pressed, finding out that
+BABEL is the only possible command in this position is a simple matter of
+traversing the above semantic tree. (And this is exactly what is done by the
+C<possible_words> routine in L<App::Dochazka::CLI::Parser>.)
+
+This routine takes an optional argument which, if provided, is assumed to be a
+reference to a dispatch map. In the absence of this argument, the
+C<$dispatch_map> package variable (initialized above) is used.
+
+For this and more examples, see C<t/parser/semantic_tree.t>.
 
 =cut
 
-sub process_command {
-    my ( $cmd ) = @_;
-   
-    my $r = parse( $cmd );                        # parse the command string
-    if ( not @{ $r->{ts} } ) {
-        return $CELL->status_err( 'DOCHAZKA_CLI_PARSE_ERROR' );
+sub generate_semantic_tree {
+    my ( $dm ) = @_;
+    #
+    # ( if $dm is given -- e.g., for testing --, then use it. Otherwise, use
+    # the $dispatch_map package variable )
+    #
+    if ( ! $dm ) {
+        $dm = $App::Dochazka::CLI::CommandMap::dispatch_map;
     }
-    print "Recognized command " . $r->{nc} . "\n" if $debug_mode;
 
-    my $cmdspec = look_up_command( $r->{nc} );   # get the handler coderef
-    if ( ref( $cmdspec ) eq 'CODE' ) {
-        my $rv = $cmdspec->( $r->{ts}, $r->{th} );   # call the handler
-        if ( ref( $rv ) eq 'ARRAY' ) {
-            my $pl;
-            my $status = send_req( @$rv );             # call send_req with the args
-            if ( ref( $status ) eq 'App::CELL::Status' ) {
-                $status->{'rest_test'} = 1;
-                return $status;
-            } else {
-                die "AAAAGGGHGHGHGHGHHHH! \$status is not a status object " . Dumper( $status );
+    my $tree = {};
+
+    foreach my $cmd ( keys %$dm ) {
+        
+        # split the command into tokens
+        my @tokens = split( ' ', $cmd );
+        
+        # walk the tokens - $subtree is a pointer into $tree
+        my $subtree = $tree;
+        for ( my $i = 0; $i < @tokens; $i += 1 ) {
+            my $token = $tokens[$i];
+            if ( ! exists( $subtree->{ $token } ) ) {
+                # create new node
+                $subtree->{ $token } = {};
             }
-        } else {
-            return $rv;
+            # add child to existing node
+            $subtree = $subtree->{ $token };
         }
+        
     }
-    return $CELL->status_err( 'DOCHAZKA_CLI_PARSE_ERROR' );
 
+    # return the tree we built
+    #print Dumper( $tree ), "\n";
+    return $tree;
+}
+
+
+=head2 look_up_command
+
+Given a normalized command string such as "GET BUGREPORT", look it up in the
+dispatch map and return the corresponding coderef, or nothing if the lookup
+fails.
+
+=cut
+
+sub look_up_command {
+    my ( $cmd ) = @_;
+
+    # check for undef and empty string
+    return unless defined( $cmd ) and $cmd =~ m/\S/;
+
+    # check for a match
+    if ( my $coderef = $App::Dochazka::CLI::CommandMap::dispatch_map->{ uc( $cmd ) } ) {
+        return $coderef;
+    }
+
+    # failure - return nothing
+    return;
 }
 
 
@@ -240,7 +330,7 @@ Given a token stack, return the list of possible tokens.
 sub possible_words {
    my ( $ts ) = @_;
 
-   $semantic_tree = generate_semantic_tree() unless %$semantic_tree;
+   $semantic_tree = generate_semantic_tree() unless defined( $semantic_tree ) and %$semantic_tree;
 
    my $pointer = $semantic_tree;
    for ( my $i = 0 ; $i < @$ts ; $i += 1 ) {
@@ -256,5 +346,39 @@ sub possible_words {
 }
 
 
-1;
+=head2 process_command
 
+Given a command entered by the user, process it and return the result.
+
+=cut
+
+sub process_command {
+    my ( $cmd ) = @_;
+   
+    my $r = parse( $cmd );                        # parse the command string
+    if ( not @{ $r->{ts} } ) {
+        return $CELL->status_err( 'DOCHAZKA_CLI_PARSE_ERROR' );
+    }
+    print "Recognized command " . $r->{nc} . "\n" if $debug_mode;
+
+    my $cmdspec = look_up_command( $r->{nc} );   # get the handler coderef
+    if ( ref( $cmdspec ) eq 'CODE' ) {
+        my $rv = $cmdspec->( $r->{ts}, $r->{th} );   # call the handler
+        if ( ref( $rv ) eq 'ARRAY' ) {
+            my $pl;
+            my $status = send_req( @$rv );             # call send_req with the args
+            if ( ref( $status ) eq 'App::CELL::Status' ) {
+                $status->{'rest_test'} = 1;
+                return $status;
+            } else {
+                die "AAAAGGGHGHGHGHGHHHH! \$status is not a status object " . Dumper( $status );
+            }
+        } else {
+            return $rv;
+        }
+    }
+    return $CELL->status_err( 'DOCHAZKA_CLI_PARSE_ERROR' );
+
+}
+
+1;
