@@ -39,7 +39,7 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $meta $site );
-use App::Dochazka::CLI::CommandMap qw( look_up_command );
+use App::Dochazka::CLI::Parser qw( look_up_command process_command );
 use Exporter qw( import );
 use Test::More;
 
@@ -48,18 +48,18 @@ use Test::More;
 
 =head1 NAME
 
-App::Dochazka::CLI::Test - Various reusable test routines
+App::Dochazka::CLI::Test - Reusable test routines
 
 
 
 
 =head1 VERSION
 
-Version 0.184
+Version 0.191
 
 =cut
 
-our $VERSION = '0.184';
+our $VERSION = '0.191';
 
 
 
@@ -69,7 +69,9 @@ our $VERSION = '0.184';
 =cut
 
 our @EXPORT_OK = qw( 
+    delete_interval_test
     do_parse_test
+    fetch_interval_test
 );
 
 
@@ -78,11 +80,29 @@ our @EXPORT_OK = qw(
 =head1 FUNCTIONS
 
 
+=head2 delete_interval
+
+=cut
+
+sub delete_interval_test {
+    my ( $iid ) = @_;
+    note( 'delete the interval we just created' );
+    note( my $cmd = "DELETE INTERVAL IID $iid" );
+    my $rv = process_command( $cmd );
+    is( ref( $rv ), 'App::CELL::Status' );
+    is( $rv->level, 'OK' );
+    is( $rv->code, 'DOCHAZKA_CUD_OK', "IID $iid deleted" );
+}
+
+
 =head2 do_parse_test
 
-A piece of code we run for entries in CommandMap.pm -- needs the "normalized
-command" ('nc' property returned by parse()); do not send it the raw command
-entered by the user!
+A piece of testing code we run for entries in CommandMap.pm 
+
+Takes the "normalized command", i.e. the C<nc> property returned by C<parse()>;
+especially do not send it the raw command entered by the user!
+
+For usage, see C<< t/parser/parse_test.t >>
 
 =cut
 
@@ -96,4 +116,31 @@ sub do_parse_test {
 }
 
 
+=head2 fetch_interval_test
+
+Takes a "command component" and a search string to look for. The command
+component is inserted into 
+
+    INTERVAL FETCH $cmd_component
+
+and the search string is looked for in the response.
+
+Returns the response (payload) string for (optional) further testing.
+
+=cut
+
+sub fetch_interval_test {
+    my ( $cmd_component, $search_str ) = @_;
+
+    note( my $cmd = "INTERVAL FETCH $cmd_component" );
+    my $rv = process_command( $cmd );
+    is( ref( $rv ), 'App::CELL::Status' );
+    is( $rv->level, 'OK' );
+    is( $rv->code, 'DOCHAZKA_CLI_NORMAL_COMPLETION' );
+    like( $rv->payload, qr/Attendance intervals of worker.+$search_str/ms );
+
+    return $rv->payload;
+}
+
+
 1;
