@@ -39,7 +39,16 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $meta $site );
-use App::Dochazka::CLI qw( $current_emp $current_priv $debug_mode $prompt_date );
+use App::Dochazka::CLI qw( 
+    $current_emp 
+    $current_priv 
+    $debug_mode 
+    $prompt_date 
+    $prompt_century 
+    $prompt_year 
+    $prompt_month 
+    $prompt_day 
+);
 use App::Dochazka::CLI::TokenMap qw( $regex_map ); 
 use App::Dochazka::Model::Employee;
 use Data::Dumper;
@@ -47,6 +56,7 @@ use Date::Calc qw( check_date Add_Delta_Days );
 use Exporter 'import';
 use File::ShareDir;
 use Log::Any::Adapter;
+use Params::Validate qw( :all );
 use Scalar::Util qw( looks_like_number );
 use Time::Piece;
 use Time::Seconds;
@@ -65,11 +75,11 @@ App::Dochazka::CLI::Util - Various reusable components
 
 =head1 VERSION
 
-Version 0.184
+Version 0.191
 
 =cut
 
-our $VERSION = '0.184';
+our $VERSION = '0.191';
 
 
 
@@ -78,7 +88,7 @@ our $VERSION = '0.184';
 
 =cut
 
-our ( $t, $today, $yesterday, $tomorrow, $current_year, $current_century, $current_month );
+our ( $t, $today, $yesterday, $tomorrow );
 
 our @EXPORT_OK = qw( 
     authenticate_to_server 
@@ -92,14 +102,10 @@ our @EXPORT_OK = qw(
     refresh_current_emp 
     rest_error 
     truncate_to
-    tsrange_from_timestamps
     $t
     $today
     $yesterday
     $tomorrow
-    $current_year
-    $current_century
-    $current_month
 );
 
 
@@ -109,55 +115,63 @@ our @EXPORT_OK = qw(
 
 =head2 authenticate_to_server
 
-Takes PROPLIST with three properties:
+All communication between L<App::Dochazka::CLI> and the L<App::Dochazka::REST>
+server goes via the C<send_req> routine in L<Web::MREST::CLI::UserAgent>. This
+routine takes its connection parameters (address of REST server, nick and
+password) from the following configuration parameters:
+
+    $site->MREST_CLI_URI_BASE
+    $meta->CURRENT_EMPLOYEE_NICK
+    $meta->CURRENT_EMPLOYEE_PASSWORD
+
+The first parameter, C<MREST_CLI_URI_BASE>, is a site configuration parameter
+so it is assumed to be loaded from a configuration file. The second and third
+are meta parameters and are set by this routine.
+
+After setting the meta parameters, the routine causes a GET request for the
+C<employee/self/priv> resource to be send to the server, and uses the response
+to initialize the C<$current_emp> and C<$current_priv> variables which are
+imported from the L<App::Dochazka::CLI> package.
+
+Takes PROPLIST with two properties:
 
 =over
 
 =item C<< user >>
 
-The username to authenticate as
+The username to authenticate as (defaults to 'demo')
 
 =item C<< password >>
 
-The password to use
-
-=item C<< quiet >>
-
-(Optional) boolean value whether to "be quiet" - defaults to 0
+The password to use (defaults to the value of the C<user> parameter)
 
 =back
 
+Since this routine returns the status object returned by the "GET
+employee/self/priv" request, it is actually a wrapper around C<send_req>.
+
 =cut
 
 sub authenticate_to_server {
     my %PROPLIST = ( 
-        quiet => 0,
+        user => 'demo',
         @_,
     );
-    $PROPLIST{'user'} = $PROPLIST{'user'} || 'demo';
     $PROPLIST{'password'} = $PROPLIST{'password'} || $PROPLIST{'user'};
-    print "Authenticating to server at " . $site->MREST_CLI_URI_BASE . 
-        " as user " . $PROPLIST{'user'} . "\n"
-        unless $PROPLIST{'quiet'};
-
-    # prompt for nick if none provided in site configuration
-    #if ( ! $site->DOCHAZKA_REST_LOGIN_NICK ) {
-    #    print "Server auth nick:     ";
-    #    $meta->set( 'CURRENT_EMPLOYEE_NICK', <> );
-    #}
 
     $meta->set( 'CURRENT_EMPLOYEE_NICK', $PROPLIST{'user'} );
+    $meta->set( 'CURRENT_EMPLOYEE_PASSWORD', $PROPLIST{'password'} );
 
-    # prompt for password if necessary
-    if ( ! $PROPLIST{'quiet'} and $PROPLIST{'user'} ne 'demo' and $PROPLIST{'password'} eq 'demo' ) {
-        print "Server auth password: ";
-        my $input = <STDIN>;
-        chomp( $input ); 
-        $meta->set( 'CURRENT_EMPLOYEE_PASSWORD', $input );
-        #print "Password set to " . $meta->CURRENT_EMPLOYEE_PASSWORD . "\n";
-    } else {
-        $meta->set( 'CURRENT_EMPLOYEE_PASSWORD', $PROPLIST{'password'} );
-    }
+    ## prompt for password if necessary
+    #if ( ! $PROPLIST{'quiet'} and $PROPLIST{'user'} ne 'demo' and $PROPLIST{'password'} eq 'demo' ) {
+    #    print "Server auth password: ";
+    #    my $input = <STDIN>;
+    #    chomp( $input ); 
+    #    $meta->set( 'CURRENT_EMPLOYEE_PASSWORD', $input );
+    #    #print "Password set to " . $meta->CURRENT_EMPLOYEE_PASSWORD . "\n";
+    #} else {
+    #    $meta->set( 'CURRENT_EMPLOYEE_PASSWORD', $PROPLIST{'password'} );
+    #}
 
     # get info about us
     my $status;
@@ -167,22 +181,26 @@ sub authenticate_to_server {
         $status = $_;
     };
     if ( !ref( $status ) ) {
-        print "$status\n";
-        exit;
+        die "AGHAUFF! $status\n";
     }
     return $status unless $status->ok;
-    #print Dumper( $status );
+
+    # authentication OK, initialize package variables
     $current_emp = App::Dochazka::Model::Employee->spawn( %{ $status->payload->{'current_emp'} } );
     $current_priv = $status->payload->{'priv'};
-    return $CELL->status_ok;
+    return $CELL->status_ok( 'DOCHAZKA_CLI_AUTHENTICATION_OK' );
 }
 
 
 =head2 determine_employee
 
-Given what might possibly be an employee specification, return
-a status object that will either be an error (not OK) or contain
-the employee object in the payload.
+Given what might possibly be an employee specification (as obtained from the
+user from the EMPLOYEE_SPEC token of the command line), return a status object
+that will either be an error (not OK) or contain the employee object in the
+payload.
+
+If the employee specification is empty or undefined, the payload will contain
+the C<$current_emp> object.
 
 =cut
 
@@ -208,10 +226,12 @@ EMPLOYEE_SPEC may be "nick=...", "sec_id=...", "eid=...", or simply
 =cut
 
 sub lookup_employee {
-    my ( $s_key ) = @_;   # search key
+    my ( $s_key ) = validate_pos( @_, { type => SCALAR } );
     print "Entering " . __PACKAGE__ . "::lookup_employee with search key " . Dumper( $s_key )
         if $debug_mode;
 
+    die( "AH! Not an EMPLOYEE_SPEC" ) unless $s_key =~ m/=/;
+
     my ( $key_spec, $key ) = $s_key =~ m/^(.*)\=(.*)$/;
 
     my $status;
@@ -223,11 +243,11 @@ sub lookup_employee {
                 $status = send_req( 'GET', "employee/eid/$key" );
             }
         }
-    } elsif ( $key_spec =~ m/^nic/ ) {
+    } elsif ( $key_spec =~ m/^nic/i ) {
         $status = send_req( 'GET', "employee/nick/$key" );
-    } elsif ( $key_spec =~ m/^sec/ ) {
+    } elsif ( $key_spec =~ m/^sec/i ) {
         $status = send_req( 'GET', "employee/sec_id/$key" );
-    } elsif ( $key_spec =~ m/^eid/ ) {
+    } elsif ( $key_spec =~ m/^eid/i ) {
         $status = send_req( 'GET', "employee/eid/$key" );
     } else {
         die "AAAHAAAHHH!!! Invalid employee lookup key " . ( defined( $key_spec ) ? $key_spec : "undefined" )
@@ -266,7 +286,7 @@ sub init_cli_client {
     # initialize the LWP::UserAgent object
     Web::MREST::CLI::UserAgent::init_ua();
 
-    return $CELL->status_ok;
+    return $CELL->status_ok( 'DOCHAZKA_CLI_INIT_OK' ); 
 }
 
 
@@ -298,9 +318,12 @@ sub init_timepiece {
     $prompt_date = $today unless $prompt_date;
     $yesterday = ($t - ONE_DAY)->ymd;
     $tomorrow = ($t + ONE_DAY)->ymd;
-    $current_year = $t->year;
-    ( $current_century ) = $current_year =~ m/^(\d{2,2})/;
-    $current_month = $t->mon;
+    #$current_year = $t->year;
+    ( $prompt_year, $prompt_month, $prompt_day ) = 
+        $prompt_date =~ m/^(\d{4,4})-(\d{1,2})-(\d{1,2})/;
+    #( $current_century ) = $current_year =~ m/^(\d{2,2})/;
+    ( $prompt_century ) = $prompt_year =~ m/^(\d{2,2})/;
+    #$current_month = $t->mon;
 }
 
 
@@ -337,7 +360,7 @@ Caveats:
 =item * two-digit years
 
 If only YY is given, it is converted into YYYY by appending two digits
-corresponding to the current century (e.g. 22 becomes 2022 during 2000-2099).
+corresponding to the prompt century (e.g. 22 becomes 2022 during 2000-2099).
 
 =item * special date forms
 
@@ -351,7 +374,7 @@ The C<n> in the offset can be any number in the range 0-999.
 
 =item * no year
 
-If no year is given, the current year is used.
+If no year is given, the prompt year is used.
 
 =item * no date
 
@@ -382,11 +405,11 @@ sub normalize_date {
     if ( $rd =~ m/\A\d{4,4}-\d{1,2}-\d{1,2}\z/ ) {
         $nd = $rd;
     } elsif ( $rd =~ m/\A\d{2,2}-\d{1,2}-\d{1,2}\z/ ) {
-        # year has only two digits: add the current century
-        $nd = $current_century . $rd;
+        # year has only two digits: add the prompt century
+        $nd = $prompt_century . $rd;
     } elsif ( $rd =~ m/\A\d{1,2}-\d{1,2}\z/ ) {
-        # year omitted: add the current year
-        $nd = $current_year . '-' . $rd;
+        # year omitted: add the prompt year
+        $nd = $prompt_year . '-' . $rd;
     } elsif ( $rd =~ m/\Atod/i ) {
         $nd = $today;
     } elsif ( $rd =~ m/\Atom/i ) {
@@ -503,21 +526,27 @@ sub refresh_current_emp {
 
 =head2 rest_error
 
-Given a non-OK status object and a string briefly identifying (for the user) in
-which operation the error occurred, check for and report common errors like 404.
+Given a non-OK status object and a string briefly identifying (for the user)
+the operation during which the error occurred, construct and return a new
+L<App::CELL::Status> object bearing (in the payload) a string containing the
+"error report" - perhaps suitable for displaying to the user.  The code of that
+object is C<REST_ERROR> and its level is taken from the passed-in status
+object. The other attributes of the original (passed-in) status object are
+preserved in the returned status object as follows:
 
-Returns a true value if a common error is successfully identified and reported,
-false otherwise.
+    payload -> rest_payload
+    uri_path -> uri_path 
+    http_status -> http_status
 
 =cut
 
 sub rest_error {
-    my ( $status, $id_str ) = @_;
+    my ( $status, $oper_desc ) = @_;
     my $rv = "\n";
-    $rv .= "Entering " . __PACKAGE__ . "::rest_error ($id_str)"
+    $rv .= "Entering " . __PACKAGE__ . "::rest_error ($oper_desc)"
         if $debug_mode;
 
-    $rv .= "Error encountered on attempted operation \"$id_str\"\n";
+    $rv .= "Error encountered on attempted operation \"$oper_desc\"\n";
 
     # special handling if payload is a string
     if ( ref( $status->payload ) eq '' ) {
@@ -527,9 +556,13 @@ sub rest_error {
 
     } elsif ( ref( $status->payload ) eq 'HASH' ) {
 
-        my $http_status = $status->{'http_status'} || $status->payload->{'http_code'} || "Cannot be determined";
-        my $method = $status->payload->{'http_method'} || "Cannot be determined";
-        my $uri_path = $status->payload->{'uri_path'} || '';
+        my $http_status = $status->{'http_status'} || 
+                          $status->payload->{'http_code'} || 
+                          "Cannot be determined";
+        my $method      = $status->payload->{'http_method'} || 
+                          "Cannot be determined";
+        my $uri_path    = $status->payload->{'uri_path'} || 
+                          '';
         $rv .= "REST operation: $method $uri_path\n";
         $rv .= "HTTP status: $http_status\n";
         $rv .= "Explanation: ";
@@ -551,7 +584,7 @@ sub rest_error {
         code => 'REST_ERROR',
         payload => $rv,
         rest_payload => $status->payload,
-        rest_uri_path => $status->{'uri_path'},
+        uri_path => $status->{'uri_path'},
         http_status => $status->{'http_status'},
     );
     return $status_clone;
@@ -562,38 +595,29 @@ sub rest_error {
 
 Given a string and a maximum length (defaults to 32), truncates to that length.
 Returns a copy of the string. If any characters were actually removed in the
-truncate operation, '...' is appended.
+truncate operation, '...' is appended -- unless the maximum length is zero, in
+which case the empty string is returned.
 
 =cut
 
 sub truncate_to {
-    my ( $str, $mlen ) = @_;
+    my ( $str, $mlen ) = validate_pos( @_, 
+        { type => SCALAR|UNDEF },
+        { 
+            callbacks => {
+                'greater than or equal to zero' => sub { shift() >= 0 },
+            },
+            optional => 1,
+            type => SCALAR, 
+        },
+    );
     $mlen = 32 unless defined( $mlen );
-    my $len = length $str || 0;
+    my $len = length $str || 0;  # $str might be undef
     return $str unless $len > $mlen;
     my $str_copy = substr( $str, 0, $mlen );
     $str_copy .= '...' if $len > $mlen;
-    return $str_copy;
-}
-
-
-=head2 tsrange_from_timestamps
-
-Given two timestamps, normalize them and make a tsrange from them.
-If either of the timestamps does not normalize properly, return a NOT_OK status.
-If all goes well, return OK status with tsrange in the payload.
-
-=cut
-
-sub tsrange_from_timestamps {
-    my ( $ts1, $ts2 ) = @_;
-
-    $ts1 = normalize_timestamp( $ts1 );
-    $ts2 = normalize_timestamp( $ts2 );
-    return $CELL->status_not_ok( 'TSRANGE_DOES_NOT_COMPUTE' ) unless $ts1 and $ts2;
-
-    return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION',
-        payload => "[ $ts1, $ts2 )" );
+    $str_copy = '' if $mlen == 0;
+    return $str_copy;  # might be undef
 }
 
 
